Description Usage Arguments Value
View source: R/extract_reference.R
Extracts the reference term for each variable in a logistic regression.
1 |
x |
A list containing the variables and their terms |
y A list containing the extracted reference term
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.