Description Usage Arguments Value Examples
Creates a forest plot
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 |
model |
A fitted logistic regression model object |
include.intercept |
Whether to include the model intercept within the plot |
categories |
A named list containing the grouping of terms (e.g. list(Race = c("RACE"), SocioDemographics = c("AGE", "SEX"))) |
color.scheme |
A named list containing the coloring for each category |
title |
Plot title |
xlab |
x label |
ylab |
y label |
errorbar |
Whether to draw errorbars |
errorbar.width |
The width of the errorbars |
linetype |
The linetype of the reference line |
point.size |
Point size |
point.alpha |
Alpha value of the points |
ggtheme |
ggplot theme |
... |
Other parameters passed to ggplot |
A forest plot
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.