Description Usage Arguments Value Examples
View source: R/map_categories.R
Given a dictionary of categories, this function will create a "category" column in the data frame, which enables users color the forest plot not only by its variable name but also pre-defined categories
1 | map_categories(df, x)
|
df |
A dataframe containing model results |
x |
A named list |
A dataframe
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.